Index: src/core/SkMatrix.cpp |
diff --git a/src/core/SkMatrix.cpp b/src/core/SkMatrix.cpp |
index f5e4e803f2931b1219edab3611ecc72a382dadac..13a9ac28f0a715e59cdf3138aef84f3321944353 100644 |
--- a/src/core/SkMatrix.cpp |
+++ b/src/core/SkMatrix.cpp |
@@ -858,7 +858,7 @@ bool SkMatrix::invertNonIdentity(SkMatrix* inv) const { |
// translate only |
inv->setTranslate(-fMat[kMTransX], -fMat[kMTransY]); |
} |
- } else { // inv is NULL, just check if we're invertible |
+ } else { // inv is nullptr, just check if we're invertible |
if (!fMat[kMScaleX] || !fMat[kMScaleY]) { |
invertible = false; |
} |
@@ -878,7 +878,7 @@ bool SkMatrix::invertNonIdentity(SkMatrix* inv) const { |
SkMatrix* tmp = inv; |
SkMatrix storage; |
- if (applyingInPlace || NULL == tmp) { |
+ if (applyingInPlace || nullptr == tmp) { |
tmp = &storage; // we either need to avoid trampling memory or have no memory |
} |